Function canonical_manifest_bytes
pub fn canonical_manifest_bytes(
manifest_toml: &str,
) -> Result<Vec<u8>, PluginError>Expand description
Compute the canonical bytes of a manifest for signing/verification.
This strips the exact root signature and publisher_key fields from the
TOML document and returns the remaining bytes. Nested fields with those
names remain signed, including fields in a plugin config schema.